@@ -25,6 +25,7 @@
 #include <string.h>
 #include <time.h>
 #include <stdlib.h>
+#include <locale.h>
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -594,7 +595,7 @@ help_cb (GtkAction * action, gpointer data)
 {
   GError *error = NULL;
 
-  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (window)), "ghelp:gnibbles", gtk_get_current_event_time (), &error);
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (window)), "help:gnibbles", gtk_get_current_event_time (), &error);
   if (error)
     g_warning ("Failed to show help: %s", error->message);
   g_clear_error (&error);
@@ -891,6 +892,11 @@ main (int argc, char **argv)
   int i;
   GError *error = NULL;
 
+  setlocale (LC_ALL, "");
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+
   games_scores_startup ();
 
   g_set_application_name (_("Nibbles"));
